@@ -16,8 +16,9 @@ import datetime as dt
 
 import numpy as np
 
-from sentinelhub.time_utils import iso_to_datetime
+from sentinelhub import parse_time_interval
 from eolearn.core import EOTask, FeatureType
+from eolearn.core.utilities import renamed_and_deprecated
 
 
 LOGGER = logging.getLogger(__name__)
@@ -79,7 +80,7 @@ class SimpleFilterTask(EOTask):
         return eopatch
 
 
-class FilterTimeSeries(SimpleFilterTask):
+class FilterTimeSeriesTask(SimpleFilterTask):
     """
     Removes all frames in the time-series with dates outside the user specified time interval.
     """
@@ -107,8 +108,7 @@ class FilterTimeSeries(SimpleFilterTask):
 
         if 'time_interval' in eopatch.meta_info:
 
-            start_time, end_time = [iso_to_datetime(x) if isinstance(x, str)
-                                    else x for x in eopatch.meta_info['time_interval']]
+            start_time, end_time = parse_time_interval(eopatch.meta_info['time_interval'])
             eopatch.meta_info['time_interval'] = (max(start_time, self.start_date),
                                                   min(end_time, self.end_date))
 
@@ -212,3 +212,9 @@ class ValueFilloutTask(EOTask):
         eopatch[self.feature] = data
 
         return eopatch
+
+
+@renamed_and_deprecated
+class FilterTimeSeries(FilterTimeSeriesTask):
+    """ A deprecated version of FilterTimeSeriesTask
+    """
